@@ -58,11 +58,11 @@ App::Dochazka::REST - Dochazka REST server
 
 =head1 VERSION
 
-Version 0.473
+Version 0.474
 
 =cut
 
-our $VERSION = '0.473';
+our $VERSION = '0.474';
 
 
 =head2 Development status
@@ -1211,35 +1211,16 @@ debug messages will be logged.
 
 
 
-=head2 init
+=head2 init_no_db
 
 Load site configuration and set up logging.
 
-=cut
+Takes an optional PARAMHASH which is passed to C<< _load_config() >>. This
+PARAMHASH can be used to stipulate a C<<sitedir>> and toggle verbose and debug
+modes.
 
-sub init {
-    # initialize the $dbix_conn singleton
-    App::Dochazka::REST::ConnBank::init_singleton(
-        $site->DOCHAZKA_DBNAME,
-        $site->DOCHAZKA_DBUSER,
-        $site->DOCHAZKA_DBPASS,
-    );
-
-    my $eids = get_eid_of( $dbix_conn, "root", "demo" );
-    $site->set( 'DOCHAZKA_EID_OF_ROOT', $eids->{'root'} );
-    $site->set( 'DOCHAZKA_EID_OF_DEMO', $eids->{'demo'} );
-}
-
-
-=head2 init_no_db
-
-Load site configuration and set up logging. Intended for use from the C<init>
-method as well as from L<App::Dochazka::REST> unit tests that need to connect to
-the pristine database using C<connect_db_pristine>. 
-
-Takes an optional PARAMHASH which is passed to C<< $CELL->load >>. The
-L<App::Dochazka::REST> distro sharedir is loaded as the first sitedir, before any
-sitedir specified in the PARAMHASH is loaded. Call examples:
+The L<App::Dochazka::REST> distro sharedir is loaded as the first sitedir,
+before any sitedir specified in the PARAMHASH is loaded. Call examples:
 
     my $status = $REST->init_no_db;
     my $status = $REST->init_no_db( verbose => 1 );
